@@ -12,11 +12,14 @@ use warnings;
 	# gives us create_form_meta function
 	use Form::Tiny::Utils qw(:meta_handlers);
 
-	# we need this role mixed in
-	with qw(Form::Tiny::Form);
+	# mixing in Form::Tiny early will give us form_meta method
+	# proper form_meta will setup the metamodel for a form
+	with 'Form::Tiny';
 
 	# meta roles go into the qw()
-	create_form_meta(__PACKAGE__, qw());
+	# class roles goes into set_form_roles method call
+	create_form_meta(__PACKAGE__, qw())
+		->set_form_roles(['Form::Tiny::Form']);
 
 	# add a requried field
 	__PACKAGE__->form_meta->add_field(
