@@ -12,7 +12,7 @@ use Form::Tiny::Error;
 use Form::Tiny::Utils qw(try get_package_form_meta);
 use Moo::Role;
 
-our $VERSION = '2.05';
+our $VERSION = '2.06';
 
 has 'field_defs' => (
 	is => 'ro',
@@ -385,14 +385,6 @@ sub _ft_clear_errors
 	return;
 }
 
-sub form_meta
-{
-	my ($self) = @_;
-	my $package = defined blessed $self ? blessed $self : $self;
-
-	return get_package_form_meta($package);
-}
-
 # This fixes form inheritance for other role systems than Moose
 around DOES => sub {
 	my ($orig, $self, @args) = @_;
